@@ -36,7 +36,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.40';
+our $VERSION = '2.41';
 
 =head1 SYNOPSIS
 
@@ -233,6 +233,11 @@ has 'log' => (
 #    default => \&init_log,
 );
 
+has 'command_log' => (
+    traits => ['NoGetopt'],
+    is => 'rw',
+);
+
 has 'logfile' => (
     traits  => ['String', 'NoGetopt'],
     is => 'rw',
@@ -265,17 +270,7 @@ sub set_logdir{
     $logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
 
     $DB::single=2;
-#    #forget this it makes the log files too log
     $logdir =~ s/\.log$//;
-    #$logdir =~ s/\.md//g;
-
-#    #Don't want to overwrite existing logdirs
-#    #Actually don't care because all CMD files should be fine
-#    while(-d $logdir){
-#        sleep(1);
-#        $logdir = $self->outdir."/".$self->logname."_".$self->set_logfile;
-#        $logdir =~ s/\.log$//;
-#    }
 
     make_path($logdir) if ! -d $logdir;
     return $logdir;
@@ -293,7 +288,6 @@ sub set_logfile{
     my $dt = DateTime->now();
     $dt =~ s/[^\w]/_/g;
     return "$dt.log";
-    #return $dt;
 }
 
 =head2 init_log
@@ -388,7 +382,8 @@ sub _log_commands {
     $self->prepend_logfile("CMD".$self->counter."_PID_$pid"."_DT_");
     $DB::single=2;
 
-    my $logger = $self->init_log;
+    #my $logger = $self->init_log;
+    $self->command_log($self->init_log);
 
     #Start running job
     my ($infh,$outfh,$errfh);
@@ -410,17 +405,9 @@ sub _log_commands {
     $DB::single=2;
 
 
-    #if($self->show_processid){
-        #$logger->debug("Starting job ".$self->counter." with PID $cmdpid\nCmd is ".$self->cmd);
-    #}
-    #else{
-        #$logger->debug("Starting job ".$self->counter." with PID $cmdpid");
-        #$logger->debug("Cmd is ".$self->cmd);
-    #}
+    $self->log_messages("debug", "Starting Job: ".$self->counter." \nCmd is ".$self->cmd, $cmdpid);
 
-    $self->log_messages($logger, "debug", "Starting Job: ".$self->counter." \nCmd is ".$self->cmd, $cmdpid);
-
-    $logger->debug("@ is ".$@) if $@;
+    $self->command_log->debug("@ is ".$@) if $@;
 
     $DB::single=2;
 
@@ -437,8 +424,7 @@ sub _log_commands {
             my $len = sysread $fh, $line, 4096;
             if(not defined $len){
                 # There was an error reading
-                #$logger->fatal("Error from child: $!");
-                $self->log_messages($logger, "fatal", "Error from child: $!" , $cmdpid)
+                $self->log_messages("fatal", "Error from child: $!" , $cmdpid)
             } elsif ($len == 0){
                 # Finished reading from this FH because we read
                 # 0 bytes.  Remove this handle from $sel.
@@ -446,13 +432,11 @@ sub _log_commands {
                 next;
             } else { # we read data alright
                 if($fh == $outfh) {
-                    #$logger->info($line);
-                    $self->log_messages($logger, "info", $line, $cmdpid)
+                    $self->log_messages("info", $line, $cmdpid)
                 } elsif($fh == $errfh) {
-                    #$logger->error($line);
-                    $self->log_messages($logger, "error", $line, $cmdpid)
+                    $self->log_messages("error", $line, $cmdpid)
                 } else {
-                    $logger->fatal("Shouldn't be here!\n");
+                    $self->command_log->fatal("Shouldn't be here!\n");
                 }
             }
         }
@@ -463,8 +447,7 @@ sub _log_commands {
 
     $DB::single=2;
 
-    #$logger->debug("Finishing job ".$self->counter." with PID $cmdpid and ExitCode $exitcode");
-    $self->log_messages($logger, "debug", "Finishing job ".$self->counter." with ExitCode $exitcode", $cmdpid);
+    $self->log_messages("debug", "Finishing job ".$self->counter." with ExitCode $exitcode", $cmdpid);
 
     my $dt2 = DateTime->now();
     my $duration = $dt2 - $dt1;
@@ -472,22 +455,20 @@ sub _log_commands {
         pattern => '%Y years, %m months, %e days, %H hours, %M minutes, %S seconds'
     );
 
-    #$logger->info("Total execution time ".$format->format_duration($duration));
-    $self->log_messages($logger, "info", "Total execution time ".$format->format_duration($duration), $cmdpid);
+    $self->log_messages("info", "Total execution time ".$format->format_duration($duration), $cmdpid);
 
     return $exitcode;
 }
 
 sub log_messages{
-    my($self, $logger, $level, $message, $cmdpid)  = @_;
+    my($self, $level, $message, $cmdpid)  = @_;
 
     if($self->show_processid){
-        $logger->$level("PID: $cmdpid\t$message");
+        $self->command_log->$level("PID: $cmdpid\t$message");
     }
     else{
-        $logger->$level($message);
+        $self->command_log->$level($message);
     }
-
 }
 
 
